@@ -1,5 +1,5 @@
 package Net::Async::Ping;
-$Net::Async::Ping::VERSION = '0.001001';
+$Net::Async::Ping::VERSION = '0.002000';
 use strict;
 use warnings;
 
@@ -9,7 +9,8 @@ use Module::Runtime 'use_module';
 use namespace::clean;
 
 my %method_map = (
-   tcp => 'TCP',
+   tcp  => 'TCP',
+   icmp => 'ICMP',
 );
 
 sub new {
@@ -22,7 +23,7 @@ sub new {
 
    my @args;
    if (ref $_[0]) {
-      @args = ($_[0])
+      @args = (%{$_[0]})
    } else {
       my ($default_timeout, $bytes, $device, $tos, $ttl) = @_;
 
@@ -51,7 +52,7 @@ Net::Async::Ping - asyncronously check remote host for reachability
 
 =head1 VERSION
 
-version 0.001001
+version 0.002000
 
 =head1 SYNOPSIS
 
@@ -70,11 +71,29 @@ version 0.001001
     say "the host is down!!!";
  });
 
+ # With a timer
+ my $timer;
+ $timer = IO::Async::Timer::Periodic->new(
+    interval => 1,
+    on_tick  => sub {
+        $timer->adopt_future(
+            $p->ping($loop, 'myrealbox.com')
+                ->on_done(sub { say "good job the host is running!" })
+                ->on_fail(sub { say "the host is down!!!" })
+                ->else_done
+        );
+    },
+ );
+ $timer->start;
+
+ $l->add( $timer );
+ $l->run;
+
 =head1 DESCRIPTION
 
 This module's goal is to eventually be able to test remote hosts
 on a network with a number of different socket types and protocols.
-Currently it only supports TCP, but UDP, ICMP, and Syn are planned.
+Currently it only supports TCP and ICMP, but UDP, and Syn are planned.
 If you need one of those feel free to work up a patch.
 
 This module was originally forked off of L<Net::Ping>, so it shares B<some> of it's interface, but only where it makes sense.
@@ -88,11 +107,10 @@ This module was originally forked off of L<Net::Ping>, so it shares B<some> of i
  );
 
 All arguments to new are optional, but if you want to provide one in the
-middle you must provide all the ones to the left of it.  The default (and
-currently only) protocol is C<tcp>.  The default timeout is 5 seconds.
-bytes does not apply to C<tcp>.  C<device> is what host to bind the
-socket to, ie what to ping B<from>.  Neither tos nor ttl apply to C<tcp>
-currently.
+middle you must provide all the ones to the left of it.  The default
+protocol is C<tcp>.  The default timeout is 5 seconds.
+C<device> is what host to bind the socket to, ie what to ping B<from>.
+C<bytes>, C<tos> and C<ttl> do not currently apply.
 
 Alternately, you can use a new constructor:
 
@@ -101,22 +119,31 @@ Alternately, you can use a new constructor:
       default_timeout => 10,
       bind            => '192.168.1.1',
       port_number     => 80,
-      service_check   => 1,
    },
  );
 
-All of the above arguments are optional.  Service check, which is off
-by default, will cause ping to fail if the host refuses connection to
-the selected port (7 by default.)  Bind is the same as device from before.
-=method ping
+All of the above arguments are optional. Bind is the same as device from
+before.
+
+See L<Net::Async::Ping::TCP> and L<Net::Async::Ping::ICMP> for module specific
+options.
+
+=head2 ping
 
  my $future = $p->ping($loop, $host, $timeout);
 
-Returns a L<Future> representing the ping.  C<loop> should be an L<IO::Async::Loop>, host is the host, and timeout is optional and defaults to the default set above.
+Returns a L<Future> representing the ping.  C<loop> should be an
+L<IO::Async::Loop>, host is the host, and timeout is optional and defaults to
+the default set above.
 
-The future will always terminate with the hi resolution time it took to
-check for liveness.  The success or failure is checked by introspecting
-the future itself.
+It's also possible to omit the $loop, and add the pinger to a loop afterwards:
+
+ my $loop = IO::Async::Loop->new;
+ $p->ping($host);
+ $loop->add( $p );
+
+The return value of the future depends on the protocol. See
+L<Net::Async::Ping::TCP> and L<Net::Async::Ping::ICMP>.
 
 =head1 AUTHOR
 
@@ -124,7 +151,7 @@ Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Arthur Axel "fREW" Schmidt.
+This software is copyright (c) 2017 by Arthur Axel "fREW" Schmidt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
